boto v2.5.1 — boto v2.25.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

# boto v2.5.1

Release 2.5.1 is a bugfix release. It fixes the following critical issues: * issue 819

#### Previous topic

boto v2.5.0

#### Next topic

boto v2.5.2

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

PDF Version

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.25.0 »

© Copyright 2009,2010, Mitch Garnaat. Created using Sphinx 1.1.3.